/* Generated automatically. */
static const char configuration_arguments[] = "/local/pobj/or1k-elf-gcc-12.3.0/gcc-12.3.0/configure --enable-languages=c,c++ --enable-multilib --enable-interwork --with-gmp=/usr/local --disable-libcc1 --enable-cpp --without-isl --without-zstd --target=or1k-unknown-elf --disable-shared --disable-nls --disable-werror --prefix=/usr/local --sysconfdir=/etc --mandir=/usr/local/man --infodir=/usr/local/info --localstatedir=/var --disable-silent-rules --disable-gtk-doc";
static const char thread_model[] = "single";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { NULL, NULL} };
